Changelog
=========

v1.0.1
----------------
- Adds query filter for programming languages vocabulary. @b4oshany


v1.0.0
------------------

- Initial release.
  [b4oshany]
- Adds vocabularies for programming languages and platform types.
